@@ -1,6 +1,6 @@
 import datetime
 from .models import UserKey
-from .constants import USER_PK_SESSION_KEY
+from .constants import USER_PK_SESSION_KEY, USER_AUTH_BACKEND
 
 
 def has_mfa(request, user):
@@ -14,6 +14,8 @@ def has_mfa(request, user):
     if user_keys.exists():
         # Mark session as successful step 1 authentication
         set_expirable_var(request.session, USER_PK_SESSION_KEY, user.pk)
+        # Remember auth backend, needed to call django login function when multiple backends are used.
+        set_expirable_var(request.session, USER_AUTH_BACKEND, user.backend)
         return user_keys
     return False
 
